@@ -18,17 +18,12 @@ import BPTK_Py.config.config as config
 from ..logger import log
 from .scenario_manager import ScenarioManager
 from .scenario import SimulationScenario
+from ..modeling.model import Model
 from BPTK_Py.sdcompiler.compile import compile_xmile as compile
 
-
-#############################
-## ClASS ScenarioManagerSD ##
-#############################
-
-
-class ScenarioManagerSD(ScenarioManager):
+class ScenarioManagerSd(ScenarioManager):
     """
-    This class reads and writes scenarios and starts the file monitors for each scenario's model
+    This class reads and writes pure sd scenarios and starts the file monitors for each scenario's model
     """
 
     def __init__(self, base_points={}, base_constants={}, scenarios={}, name="", model=None, source="", filenames=[],
@@ -143,11 +138,10 @@ class ScenarioManagerSD(ScenarioManager):
             self.instantiate_model()
 
     def  get_cloned_model(self, model):
-        #TODO: looks like this should be a function of model, not of scenario manager sd
+        #TODO: clones a SimulatiomModel  - in principle this could also be part of SimulationModel
         if not model:
             return None
 
-        from ..abm import Model
         new_mod = Model(starttime=model.starttime, stoptime=model.stoptime, dt=model.dt, name=model.name)
 
 
@@ -189,12 +183,11 @@ class ScenarioManagerSD(ScenarioManager):
 
     def instantiate_model(self):
         """
-        This method generates the model. Loads the model_file from disk. If the file is not available, it will first parse the source itmx file using sd-compiler
+        This method generates the XMILE model using the XMILE compiler. Loads the model_file from disk. If the file is not available, it will first parse the source file using the xmile compiler
         :return: None
         """
 
-        # do nothing if this is an ABM model
-        from ..abm import Model
+        # do nothing if this is a hybrid model
         if isinstance(self.model, Model):
             return
 
