@@ -604,7 +604,7 @@ def factorial_(*args):
         except:
             pass
     n = parseExpression(args[0])
-    return "math.factorial({})".format(n)
+    return "math.factorial(int({}))".format(n)
 
 def step_(*args):
     args = remove_nesting(args)
@@ -676,7 +676,7 @@ def permutations_(*args):
     n = parseExpression(args[0])
     r = parseExpression(args[1])
 
-    return "( math.factorial( {} ) / math.factorial( {} - {} ) )".format(n,n,r)
+    return "( math.factorial( int({}) ) / math.factorial( int({}) - int({}) ) )".format(n,n,r)
 
 def triangular_(*args):
     args = remove_nesting(args)
